@@ -64,27 +64,27 @@ var NAVTREEINDEX =
 "annotated.html",
 "globals_defs_p.html",
 "globals_k.html",
-"group__pw__context.html#ga8970b7ecc709a445142eec2742ac4f3a",
-"group__pw__impl__link.html",
-"group__pw__link.html#ga5d3c859845886244df9d51621460f53b",
-"group__pw__port.html#ga6e316525982a94659dfd8b86d9090c02",
-"group__pw__session__manager.html#ga9c189d1f82467baaf78c4863c8320b3c",
-"group__spa__ansi.html#ga5d126113edfe9df70eb7f68a6f874c85",
-"group__spa__device.html#ga976176b17916248c604ae02498d9f648",
-"group__spa__list.html#gaf76607bd5d48aa7b41d693260a19b68e",
-"group__spa__node.html#gad3d0d597b9c901a69e6b9fd647594c76",
-"group__spa__param.html#gad3d15175ea1dfed4f9d89d6ec0ee86a1",
-"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a28a631aa7be2cf71d49eebb61de0c3fb",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaaede448d2d99717ab6758396d49ebdf3",
-"group__spa__pod.html#ga675878397d60084917d134c5882ea7e2",
-"group__spa__thread.html#ga4f716da417d838544df4e82f4670b79c",
-"page_man_pipewire_pulse_1.html",
-"structpw__client__node__events.html#a3d12bf0a63aba14bc897e4ceb51e4fe4",
-"structpw__impl__node__events.html#a0c45913c502536b96684e02449475a18",
-"structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660",
-"structspa__handle.html#aaef038ef76a15ddaf5833510535716b4",
-"structspa__pod__array__body.html#a3822d2dc2ac7c37b2a90b91daab8d271",
-"video-play_8c-example.html"
+"group__pw__context.html#ga528a327a97baf293d4765d0085719b91",
+"group__pw__impl__factory.html#ga81032931eb91354a197a6c1de9fff956",
+"group__pw__link.html#ga364b6ed143112bf432e1795503cc8e6e",
+"group__pw__port.html#ga2d08d6e2358afc05ca212a0258fb6a26",
+"group__pw__session__manager.html#ga8c6a1653431b3f9425a96aa0a6a72396",
+"group__spa__ansi.html#ga400ba03121c36fd42526652f8aa2842e",
+"group__spa__device.html#ga7caeded1f3eb1ff8ffce4cedd1b0b7c2",
+"group__spa__list.html#gaadec436f232586998917c75efeac05ab",
+"group__spa__node.html#gabb7d0304d2f9952bcf6b95041573c2a4",
+"group__spa__param.html#gac4e41d33f933cc70296e93f123d689d3",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcadf5297681fcd282838653ae2a8791130",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa877c930df72479fb16443effc07c6439",
+"group__spa__pod.html#ga5cac6d93f665bb39f005ed94a3b253e9",
+"group__spa__system.html#gad8592bcc0072a7f3e01c1c599c31a59a",
+"page_library.html#autotoc_md52",
+"structpw__client__methods.html#a2804d8a526c068a486a4e261821c9a07",
+"structpw__impl__metadata.html",
+"structpw__resource__events.html",
+"structspa__graph__node__callbacks.html#abc2bcb2b88b65f3eabe0e13d5d73f4e8",
+"structspa__param__info.html#ad470ae46aca7e354753efbb1019f34fe",
+"structspa__video__info__raw.html#acc3883d98af70282cb7536274e0edd74"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
