@@ -1,16 +1,17 @@
 var NAVTREEINDEX0 =
 {
 "annotated.html":[11,0],
+"audio-capture_8c-example.html":[13,9],
 "audio-dsp-filter_8c-example.html":[13,8],
 "audio-dsp-src_8c-example.html":[13,7],
 "audio-src_8c-example.html":[13,6],
-"bluez-session_8c-example.html":[13,22],
+"bluez-session_8c-example.html":[13,23],
 "classes.html":[11,1],
 "examples.html":[13],
-"export-sink_8c-example.html":[13,18],
-"export-source_8c-example.html":[13,19],
-"export-spa-device_8c-example.html":[13,21],
-"export-spa_8c-example.html":[13,20],
+"export-sink_8c-example.html":[13,19],
+"export-source_8c-example.html":[13,20],
+"export-spa-device_8c-example.html":[13,22],
+"export-spa_8c-example.html":[13,21],
 "functions.html":[11,2,0,0],
 "functions.html":[11,2,0],
 "functions_a.html":[11,2,0,1],
@@ -67,8 +68,8 @@ var NAVTREEINDEX0 =
 "functions_x.html":[11,2,0,24],
 "functions_y.html":[11,2,0,25],
 "functions_z.html":[11,2,0,26],
-"globals.html":[12,0,0],
 "globals.html":[12,0],
+"globals.html":[12,0,0],
 "globals_a.html":[12,0,6],
 "globals_a.html":[12,0,13],
 "globals_a.html":[12,0,1],
@@ -87,167 +88,166 @@ var NAVTREEINDEX0 =
 "globals_b.html":[12,0,16],
 "globals_b.html":[12,0,17],
 "globals_b.html":[12,0,18],
-"globals_c.html":[12,0,20],
-"globals_c.html":[12,0,31],
-"globals_c.html":[12,0,30],
 "globals_c.html":[12,0,29],
-"globals_c.html":[12,0,28],
-"globals_c.html":[12,0,27],
-"globals_c.html":[12,0,26],
-"globals_c.html":[12,0,25],
-"globals_c.html":[12,0,24],
-"globals_c.html":[12,0,23],
-"globals_c.html":[12,0,22],
-"globals_c.html":[12,0,21],
-"globals_c.html":[12,0,19],
-"globals_c.html":[12,0,32],
 "globals_c.html":[12,0,33],
 "globals_c.html":[12,0,34],
 "globals_c.html":[12,0,35],
+"globals_c.html":[12,0,20],
+"globals_c.html":[12,0,19],
+"globals_c.html":[12,0,21],
+"globals_c.html":[12,0,32],
+"globals_c.html":[12,0,31],
+"globals_c.html":[12,0,30],
+"globals_c.html":[12,0,22],
+"globals_c.html":[12,0,23],
+"globals_c.html":[12,0,24],
+"globals_c.html":[12,0,28],
+"globals_c.html":[12,0,25],
+"globals_c.html":[12,0,26],
+"globals_c.html":[12,0,27],
+"globals_d.html":[12,0,36],
+"globals_d.html":[12,0,49],
+"globals_d.html":[12,0,37],
 "globals_d.html":[12,0,38],
 "globals_d.html":[12,0,39],
-"globals_d.html":[12,0,46],
 "globals_d.html":[12,0,40],
 "globals_d.html":[12,0,41],
 "globals_d.html":[12,0,42],
 "globals_d.html":[12,0,43],
 "globals_d.html":[12,0,44],
 "globals_d.html":[12,0,45],
-"globals_d.html":[12,0,37],
-"globals_d.html":[12,0,36],
+"globals_d.html":[12,0,46],
 "globals_d.html":[12,0,47],
 "globals_d.html":[12,0,48],
-"globals_d.html":[12,0,49],
 "globals_d.html":[12,0,50],
 "globals_defs.html":[12,6,0],
 "globals_defs.html":[12,6],
-"globals_defs_a.html":[12,6,1],
+"globals_defs_a.html":[12,6,2],
+"globals_defs_a.html":[12,6,8],
 "globals_defs_a.html":[12,6,7],
 "globals_defs_a.html":[12,6,6],
 "globals_defs_a.html":[12,6,5],
 "globals_defs_a.html":[12,6,4],
 "globals_defs_a.html":[12,6,3],
-"globals_defs_a.html":[12,6,2],
-"globals_defs_a.html":[12,6,8],
+"globals_defs_a.html":[12,6,1],
 "globals_defs_b.html":[12,6,9],
 "globals_defs_b.html":[12,6,10],
+"globals_defs_c.html":[12,6,19],
 "globals_defs_c.html":[12,6,18],
 "globals_defs_c.html":[12,6,17],
-"globals_defs_c.html":[12,6,14],
 "globals_defs_c.html":[12,6,16],
-"globals_defs_c.html":[12,6,19],
+"globals_defs_c.html":[12,6,15],
 "globals_defs_c.html":[12,6,20],
 "globals_defs_c.html":[12,6,21],
 "globals_defs_c.html":[12,6,22],
 "globals_defs_c.html":[12,6,23],
 "globals_defs_c.html":[12,6,13],
+"globals_defs_c.html":[12,6,14],
 "globals_defs_c.html":[12,6,12],
 "globals_defs_c.html":[12,6,11],
-"globals_defs_c.html":[12,6,15],
-"globals_defs_d.html":[12,6,29],
-"globals_defs_d.html":[12,6,24],
+"globals_defs_d.html":[12,6,28],
 "globals_defs_d.html":[12,6,25],
+"globals_defs_d.html":[12,6,24],
 "globals_defs_d.html":[12,6,26],
 "globals_defs_d.html":[12,6,27],
-"globals_defs_d.html":[12,6,28],
-"globals_defs_d.html":[12,6,30],
-"globals_defs_d.html":[12,6,31],
-"globals_defs_d.html":[12,6,32],
+"globals_defs_d.html":[12,6,29],
 "globals_defs_d.html":[12,6,33],
-"globals_defs_e.html":[12,6,34],
-"globals_defs_e.html":[12,6,35],
-"globals_defs_e.html":[12,6,36],
+"globals_defs_d.html":[12,6,32],
+"globals_defs_d.html":[12,6,31],
+"globals_defs_d.html":[12,6,30],
 "globals_defs_e.html":[12,6,37],
-"globals_defs_f.html":[12,6,42],
-"globals_defs_f.html":[12,6,38],
-"globals_defs_f.html":[12,6,39],
-"globals_defs_f.html":[12,6,41],
-"globals_defs_f.html":[12,6,43],
-"globals_defs_f.html":[12,6,44],
-"globals_defs_f.html":[12,6,45],
-"globals_defs_f.html":[12,6,46],
+"globals_defs_e.html":[12,6,36],
+"globals_defs_e.html":[12,6,35],
+"globals_defs_e.html":[12,6,34],
 "globals_defs_f.html":[12,6,47],
 "globals_defs_f.html":[12,6,40],
+"globals_defs_f.html":[12,6,41],
+"globals_defs_f.html":[12,6,42],
+"globals_defs_f.html":[12,6,43],
+"globals_defs_f.html":[12,6,44],
+"globals_defs_f.html":[12,6,39],
+"globals_defs_f.html":[12,6,38],
+"globals_defs_f.html":[12,6,45],
+"globals_defs_f.html":[12,6,46],
 "globals_defs_g.html":[12,6,48],
-"globals_defs_h.html":[12,6,49],
 "globals_defs_h.html":[12,6,50],
+"globals_defs_h.html":[12,6,49],
 "globals_defs_i.html":[12,6,68],
-"globals_defs_i.html":[12,6,67],
-"globals_defs_i.html":[12,6,66],
-"globals_defs_i.html":[12,6,65],
-"globals_defs_i.html":[12,6,64],
-"globals_defs_i.html":[12,6,59],
-"globals_defs_i.html":[12,6,63],
-"globals_defs_i.html":[12,6,61],
-"globals_defs_i.html":[12,6,60],
-"globals_defs_i.html":[12,6,62],
-"globals_defs_i.html":[12,6,58],
-"globals_defs_i.html":[12,6,57],
-"globals_defs_i.html":[12,6,56],
-"globals_defs_i.html":[12,6,55],
 "globals_defs_i.html":[12,6,54],
-"globals_defs_i.html":[12,6,53],
-"globals_defs_i.html":[12,6,52],
+"globals_defs_i.html":[12,6,55],
+"globals_defs_i.html":[12,6,56],
+"globals_defs_i.html":[12,6,57],
+"globals_defs_i.html":[12,6,58],
+"globals_defs_i.html":[12,6,59],
+"globals_defs_i.html":[12,6,60],
+"globals_defs_i.html":[12,6,61],
+"globals_defs_i.html":[12,6,62],
 "globals_defs_i.html":[12,6,51],
+"globals_defs_i.html":[12,6,52],
+"globals_defs_i.html":[12,6,63],
+"globals_defs_i.html":[12,6,64],
+"globals_defs_i.html":[12,6,65],
+"globals_defs_i.html":[12,6,66],
+"globals_defs_i.html":[12,6,67],
+"globals_defs_i.html":[12,6,53],
 "globals_defs_j.html":[12,6,69],
+"globals_defs_k.html":[12,6,70],
+"globals_defs_k.html":[12,6,71],
+"globals_defs_k.html":[12,6,72],
+"globals_defs_k.html":[12,6,73],
 "globals_defs_k.html":[12,6,80],
 "globals_defs_k.html":[12,6,79],
+"globals_defs_k.html":[12,6,75],
 "globals_defs_k.html":[12,6,78],
 "globals_defs_k.html":[12,6,77],
 "globals_defs_k.html":[12,6,76],
-"globals_defs_k.html":[12,6,75],
 "globals_defs_k.html":[12,6,74],
-"globals_defs_k.html":[12,6,73],
-"globals_defs_k.html":[12,6,72],
-"globals_defs_k.html":[12,6,71],
-"globals_defs_k.html":[12,6,70],
-"globals_defs_l.html":[12,6,86],
-"globals_defs_l.html":[12,6,82],
-"globals_defs_l.html":[12,6,97],
-"globals_defs_l.html":[12,6,96],
-"globals_defs_l.html":[12,6,95],
 "globals_defs_l.html":[12,6,94],
-"globals_defs_l.html":[12,6,93],
-"globals_defs_l.html":[12,6,92],
-"globals_defs_l.html":[12,6,91],
-"globals_defs_l.html":[12,6,90],
-"globals_defs_l.html":[12,6,88],
-"globals_defs_l.html":[12,6,81],
-"globals_defs_l.html":[12,6,83],
-"globals_defs_l.html":[12,6,84],
-"globals_defs_l.html":[12,6,85],
-"globals_defs_l.html":[12,6,87],
+"globals_defs_l.html":[12,6,95],
+"globals_defs_l.html":[12,6,96],
+"globals_defs_l.html":[12,6,97],
 "globals_defs_l.html":[12,6,89],
-"globals_defs_m.html":[12,6,106],
-"globals_defs_m.html":[12,6,105],
-"globals_defs_m.html":[12,6,107],
-"globals_defs_m.html":[12,6,108],
+"globals_defs_l.html":[12,6,90],
+"globals_defs_l.html":[12,6,91],
+"globals_defs_l.html":[12,6,92],
+"globals_defs_l.html":[12,6,93],
+"globals_defs_l.html":[12,6,88],
+"globals_defs_l.html":[12,6,87],
+"globals_defs_l.html":[12,6,86],
+"globals_defs_l.html":[12,6,85],
+"globals_defs_l.html":[12,6,84],
+"globals_defs_l.html":[12,6,83],
+"globals_defs_l.html":[12,6,82],
+"globals_defs_l.html":[12,6,81],
 "globals_defs_m.html":[12,6,98],
+"globals_defs_m.html":[12,6,109],
 "globals_defs_m.html":[12,6,99],
 "globals_defs_m.html":[12,6,100],
 "globals_defs_m.html":[12,6,101],
 "globals_defs_m.html":[12,6,102],
 "globals_defs_m.html":[12,6,103],
 "globals_defs_m.html":[12,6,104],
+"globals_defs_m.html":[12,6,105],
+"globals_defs_m.html":[12,6,106],
+"globals_defs_m.html":[12,6,107],
+"globals_defs_m.html":[12,6,108],
 "globals_defs_n.html":[12,6,114],
+"globals_defs_n.html":[12,6,110],
+"globals_defs_n.html":[12,6,111],
+"globals_defs_n.html":[12,6,112],
 "globals_defs_n.html":[12,6,113],
+"globals_defs_n.html":[12,6,117],
 "globals_defs_n.html":[12,6,116],
 "globals_defs_n.html":[12,6,115],
-"globals_defs_n.html":[12,6,109],
-"globals_defs_n.html":[12,6,111],
-"globals_defs_n.html":[12,6,110],
-"globals_defs_n.html":[12,6,112],
-"globals_defs_p.html":[12,6,136],
-"globals_defs_p.html":[12,6,135],
-"globals_defs_p.html":[12,6,134],
+"globals_defs_p.html":[12,6,131],
+"globals_defs_p.html":[12,6,132],
 "globals_defs_p.html":[12,6,133],
+"globals_defs_p.html":[12,6,130],
+"globals_defs_p.html":[12,6,134],
+"globals_defs_p.html":[12,6,135],
+"globals_defs_p.html":[12,6,147],
+"globals_defs_p.html":[12,6,146],
+"globals_defs_p.html":[12,6,143],
 "globals_defs_p.html":[12,6,120],
-"globals_defs_p.html":[12,6,121],
-"globals_defs_p.html":[12,6,122],
-"globals_defs_p.html":[12,6,123],
-"globals_defs_p.html":[12,6,124],
-"globals_defs_p.html":[12,6,128],
-"globals_defs_p.html":[12,6,125],
-"globals_defs_p.html":[12,6,126],
-"globals_defs_p.html":[12,6,127]
+"globals_defs_p.html":[12,6,122]
 };
