@@ -1,5 +1,26 @@
 var NAVTREEINDEX21 =
 {
+"structspa__graph__node__callbacks.html#abc2bcb2b88b65f3eabe0e13d5d73f4e8":[10,8,5,4,2],
+"structspa__graph__node__callbacks.html#acbbdda8c4d517ce24ee12cad1c4e60ec":[10,8,5,4,0],
+"structspa__graph__port.html":[10,8,5,6],
+"structspa__graph__port.html#a2010d31b7d56fef0f5a8eeb4188e7ff6":[10,8,5,6,1],
+"structspa__graph__port.html#a6a077a5cc2c1115b43d05208bb072208":[10,8,5,6,3],
+"structspa__graph__port.html#a7139cc16698356c2fc915149d45a741f":[10,8,5,6,5],
+"structspa__graph__port.html#a8ee1612c0aaef539c9270761f3d6d8b6":[10,8,5,6,4],
+"structspa__graph__port.html#ac60bcc3482ad354bc5ae32d3cade3a02":[10,8,5,6,2],
+"structspa__graph__port.html#af25d08a94327c7642abd9d22c1f00dee":[10,8,5,6,0],
+"structspa__graph__state.html":[10,8,5,1],
+"structspa__graph__state.html#a8f3cf9778a95b2717a5a6ac0d5b55bb9":[10,8,5,1,2],
+"structspa__graph__state.html#a98a2cfe5aa419430cefaf19e3836ce40":[10,8,5,1,1],
+"structspa__graph__state.html#ade14580f5dc43afc10b857d4233d3f99":[10,8,5,1,0],
+"structspa__handle.html":[10,8,9,5,1],
+"structspa__handle.html#a28e6fe4b4f4bdd29f007a1339cbe972a":[10,8,9,5,1,1],
+"structspa__handle.html#aaef038ef76a15ddaf5833510535716b4":[10,8,9,5,1,2],
+"structspa__handle.html#aaf5d3406480eab83a92db807bc2154c5":[10,8,9,5,1,0],
+"structspa__handle__factory.html":[10,8,9,5,4],
+"structspa__handle__factory.html#a00264d237fb8d45b1878d8ea32fbb5b2":[10,8,9,5,4,4],
+"structspa__handle__factory.html#a528ffc68aa9b406e094c04bba09bbc10":[10,8,9,5,4,0],
+"structspa__handle__factory.html#a6edd8af903eeb185389da41ee945158f":[10,8,9,5,4,1],
 "structspa__handle__factory.html#aa48d0b857861f618011a9f4a89435484":[10,8,9,5,4,2],
 "structspa__handle__factory.html#ad9e9ca49d03aed627c1c1ac5db5266d7":[10,8,9,5,4,3],
 "structspa__hook.html":[10,8,8,4,2],
@@ -228,26 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__node__methods.html#af04906b32eb2e2862e8e2e2b0ef71f0c":[10,8,6,25,11],
 "structspa__param__info.html":[10,8,7,27],
 "structspa__param__info.html#a1fcfd641de4a963a797da64eebfe7771":[10,8,7,27,1],
-"structspa__param__info.html#aafe96bbf409564bcce653d58fffb40cf":[10,8,7,27,2],
-"structspa__param__info.html#ad470ae46aca7e354753efbb1019f34fe":[10,8,7,27,0],
-"structspa__param__info.html#addb9012c8b7f7db49a4d20ff4569be79":[10,8,7,27,3],
-"structspa__plugin__loader.html":[10,8,9,6,1],
-"structspa__plugin__loader.html#a17501870cdaf04804cde83d541a31a61":[10,8,9,6,1,0],
-"structspa__plugin__loader__methods.html":[10,8,9,6,2],
-"structspa__plugin__loader__methods.html#aa91d4ff3f01f2d7c38a066b3d8bc98ca":[10,8,9,6,2,2],
-"structspa__plugin__loader__methods.html#ac03d77f832ee680b4a1b68acdbcc05d4":[10,8,9,6,2,1],
-"structspa__plugin__loader__methods.html#ae2de2d15c28cf425552bb3aa6ca0bad4":[10,8,9,6,2,0],
-"structspa__pod.html":[10,8,0,19],
-"structspa__pod.html#a3f7077ea0a9d9fedac8b7ba74cb23408":[10,8,0,19,1],
-"structspa__pod.html#ad7c483f4a522ca9bf9703f7d5baf1398":[10,8,0,19,0],
-"structspa__pod__array.html":[10,8,0,32],
-"structspa__pod__array.html#a012fbf2f9cdca9b6bbd07c9a027a5a98":[10,8,0,32,0],
-"structspa__pod__array.html#a30a4ff74b448da3df862a7bdb20dad04":[10,8,0,32,1],
-"structspa__pod__array__body.html":[10,8,0,31],
-"structspa__pod__array__body.html#a3822d2dc2ac7c37b2a90b91daab8d271":[10,8,0,31,0],
-"structspa__pod__bitmap.html":[10,8,0,30],
-"structspa__pod__bitmap.html#ad45678422944ed0fd6a3b82b976497dc":[10,8,0,30,0],
-"structspa__pod__bool.html":[10,8,0,20],
-"structspa__pod__bool.html#a0813dfc89b4ac463bbbe527dd64723a0":[10,8,0,20,2],
-"structspa__pod__bool.html#aa9db4ceb398b4e0b3ffba65b08c38c4d":[10,8,0,20,1]
+"structspa__param__info.html#aafe96bbf409564bcce653d58fffb40cf":[10,8,7,27,2]
 };
